@@ -5,6 +5,7 @@ import os
 import sys
 
 from east import applications
+from east import formatting
 from east.synonyms import synonyms
 from east import utils
 
@@ -14,12 +15,16 @@ def main():
     opts, args = getopt.getopt(args, "a:f:l:t:ds")
     opts = dict(opts)
     opts.setdefault("-a", "easa")   # Algorithm to use for computing ASTs
-    opts.setdefault("-f", "edges")  # Graph output format (also "gml" possible)
     opts.setdefault("-l", "0.6")    # Level of significance for graph construction
     opts.setdefault("-t", "0.25")   # Threshold of the matching score
+    # NOTE(msdubov): -f (output format) option takes different values for different
+    #                subcommands and its default value is set in corresponding handlers.
 
     if len(args) < 2:
-        print "Invalid syntax."
+        print("Invalid syntax: EAST should be called as:\n\n"
+              "    east <command> <subcommand> [options] args\n\n"
+              "Commands available: keyphrases.\n"
+              "Subcommands available: table/graph.")
         return 1
 
     command = args[0]
@@ -27,12 +32,17 @@ def main():
 
     if command == "keyphrases":
 
+        if len(args) < 4:
+            print('Invalid syntax. For keyphrases analysis, EAST should be called as:\n\n'
+                  '    east keyphrases <subcommand> [options] "path/to/keyphrases.txt" '
+                  '"path/to/texts/dir"')
+            return 1
+
         keyphrases_file = os.path.abspath(args[2])
         input_path = os.path.abspath(args[3])
         use_synonyms = "-s" in opts
         normalized_scores = "-d" not in opts
         ast_algorithm = opts["-a"]
-        graph_format = opts["-f"]
         significance_level = float(opts["-l"])
         score_threshold = float(opts["-t"])
 
@@ -61,15 +71,17 @@ def main():
 
             keyphrases_table = applications.keyphrases_table(keyphrases, texts, ast_algorithm,
                                                              normalized_scores, synonimizer)
-            res = u"<table>"
-            for keyphrase in sorted(keyphrases_table.keys()):
-                res += u'  <keyphrase value="%s">\n' % keyphrase
-                for text in sorted(keyphrases_table[keyphrase].keys()):
-                    res += u'    <text name="%s">' % text
-                    res += u'%.3f' % keyphrases_table[keyphrase][text]
-                    res += u'</text>\n'
-                res += u'  </keyphrase>\n'
-            res += u"</table>\n"
+            opts.setdefault("-f", "xml")  # Table output format (also "csv" possible)
+            table_format = opts["-f"].lower()
+
+            if table_format == "xml":
+                res = formatting.table2xml(keyphrases_table)
+            elif table_format == "csv":
+                res = formatting.table2csv(keyphrases_table)
+            else:
+                print ("Unknown table format: '%s'. "
+                       "Please use one of: 'xml', 'csv'." % table_format)
+                return 1
 
             print res.encode("utf-8", "ignore")
 
@@ -78,13 +90,14 @@ def main():
             graph = applications.keyphrases_graph(keyphrases, texts, significance_level,
                                                   score_threshold, ast_algorithm,
                                                   normalized_scores, synonimizer)
+
+            opts.setdefault("-f", "edges")  # Graph output format (also "gml" possible)
+            graph_format = opts["-f"].lower()
+
             if graph_format == "gml":
-                res = utils.graph2gml(graph)
+                res = formatting.graph2gml(graph)
             elif graph_format == "edges":
-                res = u""
-                for node in graph:
-                    if graph[node]:
-                        res += "%s -> %s\n" % (node, ", ".join(graph[node]))
+                res = formatting.graph2edges(graph)
             else:
                 print ("Unknown graph format: '%s'. "
                        "Please use one of: 'gml', 'edges'." % graph_format)
